@@ -72,19 +72,20 @@
 #' msaenet.rmse(dat$y.te, msasnet.pred)
 #' plot(msasnet.fit)
 
-msasnet = function(x, y,
-                   family = c('gaussian', 'binomial', 'poisson', 'cox'),
-                   init = c('snet', 'ridge'),
-                   gammas = 3.7, alphas = seq(0.05, 0.95, 0.05),
-                   tune = c('cv', 'ebic', 'bic', 'aic'),
-                   nfolds = 5L,
-                   ebic.gamma = 1,
-                   nsteps = 2L,
-                   tune.nsteps = c('max', 'ebic', 'bic', 'aic'),
-                   ebic.gamma.nsteps = 1,
-                   scale = 1,
-                   eps = 1e-4, max.iter = 10000L,
-                   seed = 1001, parallel = FALSE, verbose = FALSE) {
+msasnet = function(
+  x, y,
+  family = c('gaussian', 'binomial', 'poisson', 'cox'),
+  init   = c('snet', 'ridge'),
+  gammas = 3.7, alphas = seq(0.05, 0.95, 0.05),
+  tune   = c('cv', 'ebic', 'bic', 'aic'),
+  nfolds = 5L,
+  ebic.gamma = 1,
+  nsteps = 2L,
+  tune.nsteps = c('max', 'ebic', 'bic', 'aic'),
+  ebic.gamma.nsteps = 1,
+  scale  = 1,
+  eps    = 1e-4, max.iter = 10000L,
+  seed   = 1001, parallel = FALSE, verbose = FALSE) {
 
   if (nsteps < 2L) stop('nsteps must be an integer >= 2')
 
